@@ -15,7 +15,7 @@ def _group_left_right(tlist, ttype, value, cls,
                       check_right=lambda t: True,
                       check_left=lambda t: True,
                       include_semicolon=False):
-    [_group_left_right(sgroup, ttype, value, cls, check_right,
+    [_group_left_right(sgroup, ttype, value, cls, check_right, check_left,
                        include_semicolon) for sgroup in tlist.get_sublists()
      if not isinstance(sgroup, cls)]
     idx = 0
@@ -26,7 +26,7 @@ def _group_left_right(tlist, ttype, value, cls,
         if right is None or not check_right(right):
             token = tlist.token_next_match(tlist.token_index(token) + 1,
                                            ttype, value)
-        elif left is None or not check_right(left):
+        elif left is None or not check_left(left):
             token = tlist.token_next_match(tlist.token_index(token) + 1,
                                            ttype, value)
         else:
@@ -105,8 +105,13 @@ def group_as(tlist):
         # Currently limited to DML/DDL. Maybe additional more non SQL reserved
         # keywords should appear here (see issue8).
         return not token.ttype in (T.DML, T.DDL)
+
+    def _left_valid(token):
+        return token.ttype is not T.Keyword
+
     _group_left_right(tlist, T.Keyword, 'AS', sql.Identifier,
-                      check_right=_right_valid)
+                      check_right=_right_valid,
+                      check_left=_left_valid)
 
 
 def group_assignment(tlist):
@@ -208,6 +213,7 @@ def group_identifier_list(tlist):
                    lambda t: t.ttype == T.Number.Integer,
                    lambda t: t.ttype == T.String.Single,
                    lambda t: t.ttype == T.Name.Placeholder,
+                   lambda t: t.ttype == T.Keyword,
                    lambda t: isinstance(t, sql.Comparison),
                    lambda t: isinstance(t, sql.Comment),
                    ]
@@ -327,6 +333,20 @@ def group_functions(tlist):
         token = tlist.token_next_by_type(idx, T.Name)
 
 
+def group_order(tlist):
+    idx = 0
+    token = tlist.token_next_by_type(idx, T.Keyword.Order)
+    while token:
+        prev = tlist.token_prev(token)
+        if isinstance(prev, sql.Identifier):
+            ido = tlist.group_tokens(sql.Identifier,
+                                     tlist.tokens_between(prev, token))
+            idx = tlist.token_index(ido) + 1
+        else:
+            idx = tlist.token_index(token) + 1
+        token = tlist.token_next_by_type(idx, T.Keyword.Order)
+
+
 def group(tlist):
     for func in [
             group_comments,
@@ -335,6 +355,7 @@ def group(tlist):
             group_where,
             group_case,
             group_identifier,
+            group_order,
             group_typecasts,
             group_as,
             group_aliased,
