@@ -17,7 +17,7 @@ KEYWORDS = {
     'ANALYZE': tokens.Keyword,
     'ANY': tokens.Keyword,
     'ARE': tokens.Keyword,
-    'ASC': tokens.Keyword,
+    'ASC': tokens.Keyword.Order,
     'ASENSITIVE': tokens.Keyword,
     'ASSERTION': tokens.Keyword,
     'ASSIGNMENT': tokens.Keyword,
@@ -124,7 +124,7 @@ KEYWORDS = {
     'DELIMITER': tokens.Keyword,
     'DELIMITERS': tokens.Keyword,
     'DEREF': tokens.Keyword,
-    'DESC': tokens.Keyword,
+    'DESC': tokens.Keyword.Order,
     'DESCRIBE': tokens.Keyword,
     'DESCRIPTOR': tokens.Keyword,
     'DESTROY': tokens.Keyword,
