@@ -161,7 +161,9 @@ class Lexer(object):
     stripnl = False
     tabsize = 0
     flags = re.IGNORECASE | re.UNICODE
-    bufsize = 4096
+    DEFAULT_BUFSIZE = 4096
+    MAX_BUFSIZE = 2 ** 31
+    bufsize = DEFAULT_BUFSIZE
 
     tokens = {
         'root': [
@@ -222,7 +224,8 @@ class Lexer(object):
 
     def _decode(self, text):
         if sys.version_info[0] == 3:
-            return text
+            if isinstance(text, str):
+                return text
         if self.encoding == 'guess':
             try:
                 text = text.decode('utf-8')
@@ -231,7 +234,10 @@ class Lexer(object):
             except UnicodeDecodeError:
                 text = text.decode('latin1')
         else:
-            text = text.decode(self.encoding)
+            try:
+                text = text.decode(self.encoding)
+            except UnicodeDecodeError:
+                text = text.decode('unicode-escape')
 
         if self.tabsize > 0:
             text = text.expandtabs(self.tabsize)
@@ -322,9 +328,14 @@ class Lexer(object):
                         else:
                             assert False, "wrong state def: %r" % new_state
                         statetokens = tokendefs[statestack[-1]]
+                    # reset bufsize
+                    self.bufsize = self.DEFAULT_BUFSIZE
                     break
             else:
                 if hasmore:
+                    # we have no match, increase bufsize to parse lengthy
+                    # tokens faster (see #86).
+                    self.bufsize = min(self.bufsize * 2, self.MAX_BUFSIZE)
                     buf = stream.read(self.bufsize)
                     hasmore = len(buf) == self.bufsize
                     text = text[pos:] + self._decode(buf)
@@ -345,11 +356,13 @@ class Lexer(object):
                     break
 
 
-def tokenize(sql):
+def tokenize(sql, encoding=None):
     """Tokenize sql.
 
     Tokenize *sql* using the :class:`Lexer` and return a 2-tuple stream
     of ``(token type, value)`` items.
     """
     lexer = Lexer()
+    if encoding is not None:
+        lexer.encoding = encoding
     return lexer.get_tokens(sql)
