@@ -20,7 +20,10 @@ class Token(object):
 
     def __init__(self, ttype, value):
         self.value = value
-        self.normalized = value.upper() if ttype in T.Keyword else value
+        if ttype in T.Keyword:
+            self.normalized = value.upper()
+        else:
+            self.normalized = value
         self.ttype = ttype
         self.is_keyword = ttype in T.Keyword
         self.parent = None
@@ -196,6 +199,15 @@ class TokenList(Token):
             val = val[1:-1]
         return val
 
+    def get_token_at_offset(self, offset):
+        """Returns the token that is on position offset."""
+        idx = 0
+        for token in self.flatten():
+            end = idx + len(token.value)
+            if idx <= offset <= end:
+                return token
+            idx = end
+
     def flatten(self):
         """Generator yielding ungrouped tokens.
 
@@ -483,6 +495,13 @@ class Identifier(TokenList):
             return None
         return unicode(next_)
 
+    def get_ordering(self):
+        """Returns the ordering or ``None`` as uppercase string."""
+        ordering = self.token_next_by_type(0, T.Keyword.Order)
+        if ordering is None:
+            return None
+        return ordering.value.upper()
+
 
 class IdentifierList(TokenList):
     """A list of :class:`~sqlparse.sql.Identifier`\'s."""
